@@ -1,5 +1,5 @@
 /* 
-   Copyright (C) 2010, 2012 German A. Arias <german@xelalug.org>
+   Copyright (C) 2010, 2012, 2013 German A. Arias
 
    This file is part of FísicaLab application
 
@@ -22,8 +22,7 @@
 
 @interface FLKinematicsRigidBodies : NSObject
 {
-  id cinemaRigInfo;
+  NSArray *errors;
 }
-- (void) crearEcuaciones: (id)sender;
-- (void) setSistema: (id)sender;
+- (void) makeEquationsForData: (NSMutableDictionary *)list;
 @end
